Learn R Programming

kfino (version 1.0.0)

doutlier: doutlier defines an outlier distribution (Surface of a trapezium) and uses input parameters given in the main function kfino_fit()

Description

doutlier defines an outlier distribution (Surface of a trapezium) and uses input parameters given in the main function kfino_fit()

Usage

doutlier(y, K, expertMin, expertMax)

Value

a numeric value

Arguments

y

numeric, point

K

numeric, constant value

expertMin

numeric, the minimal weight expected by the user

expertMax

numeric, the maximal weight expected by the user

Details

this function is used to calculate an outlier distribution following a trapezium shape. \(y \mapsto \text{doutlier}(y,K,\text{expertMin},\text{expertMax})\) is the probability density function on \([\text{expertMin},\text{expertMax}]\) which is linear and verifies \(\text{doutlier}(\text{expertMax},K,\text{expertMin},\text{expertMax}) =K*\text{doutlier}(\text{expertMin},K,\text{expertMin},\text{expertMax}).\) In particular, when $K=1$ this corresponds to the uniform distribution.

Examples

Run this code
doutlier(2,5,10,45)

Run the code above in your browser using DataLab